/*
  Copyright 1991 University of Rhode Island
 
  Permission to use, copy, modify and distribute this software and its
  documentation for any purpose is hereby granted without fee, provided that
  the above copyright notice appear in all copies and that both that
  copyright notice and this permission notice appear in supporting
  documentation, and that the name of U.R.I. not be used in advertising or
  publicity pertaining to distribution of the software without specific,
  written prior permission.  U.R.I. makes no representations about the
  suitability of this software for any purpose.  It is provided "as is"
  without express or implied warranty.
 
  U.R.I. DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING ALL
  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL U.R.I.
  BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION
  OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN 
  CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

/*
  Functions to handle the list of images to be browsed. The structure is
  defined in browse-list.h The file is created by piping the output of
  ls into some file. Under vms, this file is created using dir/out=...
  The file could also be generated by some database manager as the
  response to a user's query about a certain type of image.

  Modifiactions:

  12/10/90
  Ported from vms to unix. I added the compiler switches dsp, vms, and
  unix so that this one source file may be used by the different
  implementations we have planned.

  5/8/91 - Rewrote. No compiler switches. Once lists of images were the main
  source of input into browse, but no more.
*/

/* $Log: browse-list.c,v $
 * Revision 3.4  1993/02/02  16:12:32  jimg
 * Added conditional include for debugging malloc header.
 *
 * Revision 3.3  1992/11/19  21:14:30  jimg
 * ?
 *
 * Revision 3.2  1992/11/04  18:21:58  jimg
 * Misc bug fixes.
 *
 * Revision 3.2  1992/11/04  18:21:58  jimg
 * Misc bug fixes.
 *
 * Revision 3.1  1992/10/19  14:57:32  jimg
 * Fixed minor bugs.
 *
 * Revision 3.1  1992/10/19  14:57:32  jimg
 * Fixed minor bugs.
 *
 * Revision 3.0  1992/07/28  15:24:44  jimg
 * All sources for xbrowse modified to use the libcomm.a, liberrmsg.a and new
 * dialog boxes.
 *
 * Revision 3.0  1992/07/28  15:24:44  jimg
 * All sources for xbrowse modified to use the libcomm.a, liberrmsg.a and new
 * dialog boxes.
 *
 * Revision 1.1  1992/03/23  20:39:01  jimg
 * Initial revision
 *
 */

static char rcsid[]="$Id: browse-list.c,v 3.4 1993/02/02 16:12:32 jimg Exp jimg $";

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include <sys/types.h>

#include <X11/Intrinsic.h>

#ifdef MALLOC_DEBUG
#include <malloc.h>
#endif

#include "browse-list.h"
#include "dialog.h"

static char name[256];

/*
  Open the list file; return NULL if error, otherwise return a
  FILE pointer.
*/

FILE *
open_list(path)
char *path;
{
    FILE *file;

    strcpy(name, "");		/* null the name global */

    file = fopen(path, "r");
    if (!file) {
	sys_err_dialog("Could not open `%s' as list file", path);
	path = get_filename("List Filename:", path);
	if (!path)		/* cancel */
	    return NULL;
	else
	    return open_list(path);
    }
    else
        return file;
}

void
close_list(file)
FILE *file;
{
    fclose(file);
}

/*
  Advance the file pointer to the next line of the list file, store the
  next file name in the name field, and return that name as the result.
  If at EOF, then return NULL.
*/

char *
next_filename(file)
FILE *file;
{
    if (!fgets(name, 255, file) && feof(file))
	return NULL;
    else {
	name[strlen(name)-1] = '\0'; /* fgets reads /n, overwrite it */
	return name;
    }
}
