/*
  Copyright 1991 University of Rhode Island
 
  Permission to use, copy, modify and distribute this software and its
  documentation for any purpose is hereby granted without fee, provided that
  the above copyright notice appear in all copies and that both that
  copyright notice and this permission notice appear in supporting
  documentation, and that the name of U.R.I. not be used in advertising or
  publicity pertaining to distribution of the software without specific,
  written prior permission.  U.R.I. makes no representations about the
  suitability of this software for any purpose.  It is provided "as is"
  without express or implied warranty.
 
  U.R.I. DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING ALL
  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL U.R.I.
  BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION
  OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN 
  CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

/*
  Functions to open, add information to, and close log files. Each
  browse session can have a log file in which the user may add
  information about the different images that he/she is browsing. The
  log file could then become input to an automatic ordering system or
  a DBMS.

  Modifiactions:

  12/10/90
  Ported from vms to unix.

  3/6/91
  Changed log files so that they consist only of images names - one
  per line.

  8/14/91
  Modified error message text when open_log fails.
*/

/* $Log: browse-log.c,v $
 * Revision 3.4  1993/02/02  16:12:32  jimg
 * Added conditional include for debugging malloc header.
 *
 * Revision 3.3  1992/11/19  21:14:30  jimg
 * ?
 *
 * Revision 3.2  1992/11/04  18:21:58  jimg
 * Misc bug fixes.
 *
 * Revision 3.2  1992/11/04  18:21:58  jimg
 * Misc bug fixes.
 *
 * Revision 3.1  1992/10/19  14:57:32  jimg
 * Fixed minor bugs.
 *
 * Revision 3.1  1992/10/19  14:57:32  jimg
 * Fixed minor bugs.
 *
 * Revision 3.0  1992/07/28  15:24:44  jimg
 * All sources for xbrowse modified to use the libcomm.a, liberrmsg.a and new
 * dialog boxes.
 *
 * Revision 1.1  1992/03/23  20:39:01  jimg
 * Initial revision
 *
 */

static char rcsid[]="$Id: browse-log.c,v 3.4 1993/02/02 16:12:32 jimg Exp jimg $";

#include <stdio.h>
#include <string.h>
#include <stdlib.h>

#include <sys/types.h>

#include <X11/Intrinsic.h>

#ifdef MALLOC_DEBUG
#include <malloc.h>
#endif

#include "browse-log.h"
#include "dialog.h"

/*
  Open/create a log file with 'name'. If successful return a FILE pointer,
  otherwise return NULL.
*/

FILE *
open_log(name)
char *name;
{
    FILE *log;

    log = fopen(name, "w");
    if (!log) {
	sys_err_dialog("Could not open `%s' as a log file", name);
	return NULL;
    }

    return log;
}

/*
  Close the given log file.
*/

void
close_log(log)
FILE *log;
{
    fclose(log);
}

/*
  Add information to a log file.
*/

void
add_log_entry(log, image_name)
FILE *log;
char *image_name;
{
    if (fprintf(log, "%s\n", image_name) < 0)
	sys_err_dialog("Could not write to log file");
}
