#ifndef __BROWSE_H
#define __BROWSE_H

/*
  struct definition and function declarations for browse.c

  jhrg
  
  Modifications
  
  7/19/90 - Removed navdata field from browse struct. It may be added by
  defining the symbol BROWSE_NAV.
  
  9/10/90 - Removed 'BROWSE_NAV' lines.
  
  12/10/90 - Ported to unix

  1/12/91 - Added region_defd_ps flag. Used to determine when the user has
  defined a region. This simplifies and speeds up updating the screen under
  X11.

  5/2/91 - stopped using levelByteCount; cost is now updates for every packet.
*/

struct browse {
    PYRAMID *pyramid;		/* images displayed here */
    xbt_drop_t xbt_drops[MAX_XBT_DROPS]; /* xbt data needs its own type */
    int num_xbt_drops;		/* FALSE if not displaying xbts */
    PIXMAP_MARK *hash_mark;	/* the hash mark icon */
    PIXMAP_MARK *xbt_mark;	/* the mark for xbt drops */
    FILE *log_file;		/* log file for this session */
    FILE *list;			/* list of images to browse */
    char *path;			/* path (on server) of images */
    char *name;			/* user's name */
    char **image_list;		/* names (to be browsed) */
    char **pretty_list;		/* formatted copy of the above */
    int current_image;		/* image being browsed */
    long image_list_len;	/* number of elements in above */
    int cost_thresh;		/* resolution level at which data costs $$  */
    char *image_server_info;	/* describes current image server */
    int img_srvr_logins_p;	/* TRUE if the current server requires accts */
    int img_srvr_logged_in;
				/* -- state variables -- */
    char *filename;		/* name of current image file (not pathname) */
    char auth_user_p;		/* TRUE when user `name' is authorized ($$) */
    char use_local_list_p;	/* TRUE when browsing via local list */
    char use_remote_list_p;	/* TRUE when browsing via remote list */
    char use_path_p;		/* TRUE when user browses a directory */
    char path_sent_p;		/* TRUE when path has been sent */
    char region_sent_p;		/* TRUE when user region --> server */
    char region_defd_p;		/* TRUE if user def'd a region */
    char region_hm_disp_p;	/* TRUE if region's hash marks are visible */
    char auto_zoom_p;		/* TRUE if the user wants `auto zooming' */
    char auto_region_p;		/* TRUE if the user wants `auto region' */
				/* -- operation statistics -- */
    char statistics_p;		/* statistics_p ? do stats : no stats; */
    char no_question_exit_p;	/* FALSE if we should ask `Really Quit ?' */
    char accumulate_cost_p;	/* only add to image_cost when TRUE */
    long bytes_txd;		/* number of bytes txd this image */
    int images_txd;		/* number of image txd */
    double image_cost;		/* cost of current image so far */
    double total_cost;		/* cost up to current image */
    struct timeval start_time;	/* start of image transmission */
    struct timeval end_time;	/* when transmission is done */
};

typedef struct browse BROWSE;

BROWSE *init_browse();
void free_browse();
void data_to_pyramid();
void browse_next_image();
void browse_zero_time();
void print_browse_stats();
void stop_browse_image();
double calculate_cost();
void draw_region_hash_marks();
void erase_region_hash_marks();
void mark_old_region_hash_marks();

#endif /* __BROWSE_H */
