#ifndef __COMM_H
#define __COMM_H

typedef struct xdr_tcp {
#if defined(unix) || defined(__unix)
    int socket;
#elif defined(vms)
    short socket;
#endif /* unix : vms */
    XDR *xdrs;
#if  __STDC__ == 1
    void (*err_handler)(const char *, ...);
#else
    void (*err_handler)();
#endif    
} XDR_TCP;

enum type_code {
    action_tc,
    long_tc,
    string_tc,
    opaque_tc,
    struct_tc,
    float_tc,
    double_tc,
    array_tc
};



#if  __STDC__ == 1 && !sgi

XDR_TCP * xdr_tcp_bind(int sd, int buff_size, void
		       (*error_handler)(const char *, ...));
void xdr_tcp_close(XDR_TCP *xsd);
int xdr_tcp_flush_record(XDR_TCP *xdr_tcp);
int xdr_tcp_read_poll(XDR_TCP *xdr_tcp);
int xdr_tcp_write_poll(XDR_TCP *xdr_tcp);
int xdr_tcp_set_struct (u_int s_type, u_int size, int (*coding_func)());
int xdr_tcp_set_array(u_int a_type, u_int size, u_int elem_size,
		      int (*coding_func)());
int send_action(XDR_TCP *xdr_tcp, u_int action, int flush_now);
int send_long(XDR_TCP *xdr_tcp, long data, int flush_now);
#ifndef __hpux
int send_float(XDR_TCP *xdr_tcp, float data, int flush_now);
#endif
int send_double(XDR_TCP *xdr_tcp, double data, int flush_now);
int send_string(XDR_TCP *xdr_tcp, char *str, u_int maxlen, int flush_now);
int send_struct(XDR_TCP *xdr_tcp, caddr_t struct_data, u_int s_type,
		int flush_now);
int send_array(XDR_TCP *xdr_tcp, caddr_t array, u_int size, u_int a_type,
	       int flush_now);
int send_opaque(XDR_TCP *xdr_tcp, caddr_t opaque, long size, int flush_now);
u_int get_action(XDR_TCP *xdr_tcp, int next_rec);
int get_long(XDR_TCP *xdr_tcp, long *datum, int next_rec);
int get_float(XDR_TCP *xdr_tcp, float *datum, int next_rec);
int get_double(XDR_TCP *xdr_tcp, double *datum, int next_rec);
char * get_string(XDR_TCP *xdr_tcp, char *str, int maxlen, int next_rec);
caddr_t get_struct(XDR_TCP *xdr_tcp, caddr_t struct_data, u_int *s_type,
		   int next_rec);
caddr_t get_array(XDR_TCP *xdr_tcp, caddr_t array, u_int *length,
		  u_int *a_type, int next_rec);
int get_opaque(XDR_TCP *xdr_tcp, caddr_t opaque, long *length, int next_rec);
enum type_code read_type_code(XDR_TCP *xdr_tcp, int next_rec);
u_int read_action(XDR_TCP *xdr_tcp);
int read_long(XDR_TCP *xdr_tcp, long *datum);
int read_float(XDR_TCP *xdr_tcp, float *datum);
int read_double(XDR_TCP *xdr_tcp, double *datum);
char * read_string(XDR_TCP *xdr_tcp, char *str, int maxlen);
caddr_t read_struct(XDR_TCP *xdr_tcp, caddr_t struct_data, u_int *s_type);
caddr_t read_array(XDR_TCP *xdr_tcp, caddr_t array, u_int *size,
		   u_int *a_type);
int read_opaque(XDR_TCP *xdr_tcp, caddr_t opaque, long *length);
char *get_client_address(void);
void server_accept(char *service, int port, int backlog, int (*server)(int));
void daemon_start(int ignsigcld);
void catch_sig_cld(void);

#if defined(unix) || defined(__unix)
int client_connect(char *host, char *service, int port,
		   void (*err_report)(const char *, ...));
int super_server_accept(int (*server)(int));
int xdr_tcp_accept(int listen_sd);
int xdr_tcp_listen(char *service, int port, int backlog);
#elif defined(vms)
short client_connect(char *host, char *service, int port,
		   void (*err_report)(const char *, ...));
int super_server_accept(int (*server)(short));
short xdr_tcp_accept(short listen_sd);
short xdr_tcp_listen(char *service, int port, int backlog);
#endif /* vms */

#else /* __STDC__ */

XDR_TCP * xdr_tcp_bind();
void xdr_tcp_close();
int xdr_tcp_flush_record();
int xdr_tcp_read_poll();
int xdr_tcp_write_poll();
int xdr_tcp_set_struct();
int xdr_tcp_set_array();
int send_action();
int send_long();
#ifndef __hpux
int send_float();
#endif
int send_double();
int send_string();
int send_struct();
int send_array();
int send_opaque();
u_int get_action();
int get_long();
int get_float();
int get_double();
char * get_string();
caddr_t get_struct();
caddr_t get_array();
int get_opaque();
enum type_code read_type_code();
u_int read_action();
int read_long();
int read_float();
int read_double();
char * read_string();
caddr_t read_struct();
caddr_t read_array();
int read_opaque();
void daemon_start();
void catch_sig_cld();

#if defined(unix) || defined(__unix)
int client_connect();
int super_server_accept();
int xdr_tcp_accept();
int xdr_tcp_listen();
#elif defined(vms)
short client_connect();
int super_server_accept();
short xdr_tcp_accept();
short xdr_tcp_listen();
#endif /* vms */

#endif /* __STDC__ */
#endif /* __COMM_H */
