/*
  Date computation functions.
*/

#include <stdio.h>

/* Julian date converter. Takes a julian date (the number of days since
** some distant epoch or other), and returns an int pointer to static space.
** ip[0] = month;
** ip[1] = day of month;
** ip[2] = year (actual year, like 1977, not 77 unless it was  77 a.d.);
** ip[3] = day of week (0->Sunday to 6->Saturday)
** These are Gregorian.
** Copied from Algorithm 199 in Collected algorithms of the CACM
** Author: Robert G. Tantzen, Translator: Nat Howard
*/
calcdate(jd, m, d, y, h, mi, sec)
    double jd;
    int *m, *d, *y, *h, *mi;
    double *sec;
{
    static int ret[4];

    long j = jd;
    double tmp, frac = jd - j;
    if (frac >= 0.5) {
	frac = frac - 0.5;
        j++;
    }
    else {
	frac = frac + 0.5;
    }

    ret[3] = (j + 1L) % 7L;
    j -= 1721119L;
    *y = (4L * j - 1L) / 146097L;
    j = 4L * j - 1L - 146097L * *y;
    *d = j / 4L;
    j = (4L * *d + 3L) / 1461L;
    *d = 4L * *d + 3L - 1461L * j;
    *d = (*d + 4L) / 4L;
    *m = (5L * *d - 3L) / 153L;
    *d = 5L * *d - 3 - 153L * *m;
    *d = (*d + 5L) / 5L;
    *y = 100L * *y + j;
    if (*m < 10)
	*m += 3;
    else {
	*m -= 9;
	*y += 1;
    }
    tmp = 3600.0 * (frac * 24.0);
    *h = (int) (tmp / 3600.0);
    tmp = tmp - *h * 3600.0;
    *mi = (int) (tmp / 60.0);
    *sec = tmp - *mi * 60.0;
}

int dayofweek(j)
    double j;
{
    long jd = (long) j;
    if (j - jd >= 0.5) {
	jd++;
    }
    return (jd + 1) % 7;
}

/* returns Julian day number --given a string of the form xx/yy/zz.
** To calculate the day of the week use the return value % 7.
*/

long 
julian_day (date_str)
  char *date_str;
{
  long jdn;
  int month, day, year;

  sscanf (date_str, "%d/%d/%d", &month, &day, &year);

  if (year < 100)
    year += 1900;          /* assume 20th century */
  if (year < 1000)
    year += 2000;          /* assume 21st */
  jdn = (long) year * 367 + month * 275 / 9
  - (year + (month > 2)) * 7 / 4
  - ((year - (month < 3)) / 100 + 1) * 3 / 4 + day + 1721029L;

  return (jdn);
}

