/*
  read the worm database (must be sorted in order) and write out all files
  after a starting date.
*/

#include <stdio.h>
#ifdef MALLOC_DEBUG
#include <malloc.h>
#endif 

#include "browsed-const.h"

static long get_day_number(char *src_date);

#ifdef TEST
int create_list(char *out_list, int start, int end);

int
main(int argc, char *argv[])
{
    int list_len;
    char list[MAX_IMAGES][MAX_IMAGE_NAME];
    
    if (argc != 4) {
	fprintf(stderr, "Format: make-list mm/dd/yy mm/dd/yy out-file\n");
	exit(1);
    }

    list_len = create_list(list, argv[1], argv[2]);
    if (!list_len)
	exit(1);
    else {
	int i = 0;
	FILE *out = fopen(argv[3], "w");
	
	while (i++ < list_len) {
	    fputs(list[i], out);
	}
    }

    exit(0);
}
#endif

/*
  get yyddd as a long from a date string in the form mm/dd/yy.
*/

static long
get_day_number(char *src_date)
{
    long jan_1_day, actual_day;
    char jan_1_date[16];

    sprintf(jan_1_date, "01/01/%s", strrchr(src_date, '/') + 1);
    jan_1_day = julian_day(jan_1_date);
    actual_day = julian_day(src_date);

    return ((atoi(strrchr(src_date, '/') + 1) * 1000)
	    + actual_day - jan_1_day + 1);
}

/* Julian date converter. Takes a julian date (the number of days since
** some distant epoch or other), and returns an int pointer to static space.
** ip[0] = month;
** ip[1] = day of month;
** ip[2] = year (actual year, like 1977, not 77 unless it was  77 a.d.);
** ip[3] = day of week (0->Sunday to 6->Saturday)
** These are Gregorian.
** Copied from Algorithm 199 in Collected algorithms of the CACM
** Author: Robert G. Tantzen, Translator: Nat Howard
*/
calcdate(jd, m, d, y, h, mi, sec)
    double jd;
    int *m, *d, *y, *h, *mi;
    double *sec;
{
    static int ret[4];

    long j = jd;
    double tmp, frac = jd - j;
    if (frac >= 0.5) {
	frac = frac - 0.5;
        j++;
    }
    else {
	frac = frac + 0.5;
    }

    ret[3] = (j + 1L) % 7L;
    j -= 1721119L;
    *y = (4L * j - 1L) / 146097L;
    j = 4L * j - 1L - 146097L * *y;
    *d = j / 4L;
    j = (4L * *d + 3L) / 1461L;
    *d = 4L * *d + 3L - 1461L * j;
    *d = (*d + 4L) / 4L;
    *m = (5L * *d - 3L) / 153L;
    *d = 5L * *d - 3 - 153L * *m;
    *d = (*d + 5L) / 5L;
    *y = 100L * *y + j;
    if (*m < 10)
	*m += 3;
    else {
	*m -= 9;
	*y += 1;
    }
    tmp = 3600.0 * (frac * 24.0);
    *h = (int) (tmp / 3600.0);
    tmp = tmp - *h * 3600.0;
    *mi = (int) (tmp / 60.0);
    *sec = tmp - *mi * 60.0;
}

int dayofweek(j)
    double j;
{
    long jd = (long) j;
    if (j - jd >= 0.5) {
	jd++;
    }
    return (jd + 1) % 7;
}

/* returns Julian day number --given a string of the form xx/yy/zz.
** To calculate the day of the week use the return value % 7.
*/

long 
julian_day (date_str)
  char *date_str;
{
  long jdn;
  int month, day, year;

  sscanf (date_str, "%d/%d/%d", &month, &day, &year);

  if (year < 100)
    year += 1900;          /* assume 20th century */
  if (year < 1000)
    year += 2000;          /* assume 21st */
  jdn = (long) year * 367 + month * 275 / 9
  - (year + (month > 2)) * 7 / 4
  - ((year - (month < 3)) / 100 + 1) * 3 / 4 + day + 1721029L;

  return (jdn);
}

/*
  creates a list file (`out_list') starting from `start' date and ending on
  `end' date. Memory for out_list must already be allocated. Retrun FALSE if
  an error is detected,otherwise return the number of elements in the
  `out_list' array.
*/

int
create_list(char out_list[][MAX_IMAGE_NAME], char *start, char *end)
{
    int i;
    long date_i, start_i = get_day_number(start), end_i = get_day_number(end);
    int found = FALSE, found_last = FALSE;
    char line[MAX_IMAGE_NAME], date[6];
    FILE *db = fopen(WORM_DB, "r");

    if (!db) {
	err_ret("Could not open the worm database (%s)", WORM_DB);
	return FALSE;
    }

    while (fgets(line, MAX_IMAGE_NAME, db) && !found) {

	/* extract and convert 5 year, day number characters */
	strncpy(date, strchr(line, ']') + 2, 5);
	date[6] = '\0';
	date_i = atoi(date);

	if (date_i >= start_i)
	    found = TRUE;
    }

    if (found) {

	i = 0;
	while(fgets(line, MAX_IMAGE_NAME, db)
	      && !found_last && (i < MAX_IMAGES)) {

	    /* extract and convert 5 `year and day-number' characters */
	    strncpy(date, strchr(line, ']') + 2, 5);
	    date[6] = '\0';
	    date_i = atoi(date);
	    
	    if (date_i > end_i)
		found_last = TRUE;
	    else
		strncpy(out_list[i++], line, strlen(line) - 1);
	}
    }
    else {
	err_print("Dates (%d - %d) not found", start_i, end_i);
	return FALSE;
    }

    return i ? i--: 0;		/* beacuse of post increment in strncpy(...) */
}
