/*
  Copyright 1991, 1992 University of Rhode Island
 
  Permission to use, copy, modify and distribute this software and its
  documentation for any purpose is hereby granted without fee, provided that
  the above copyright notice appear in all copies and that both that
  copyright notice and this permission notice appear in supporting
  documentation, and that the name of U.R.I. not be used in advertising or
  publicity pertaining to distribution of the software without specific,
  written prior permission.  U.R.I. makes no representations about the
  suitability of this software for any purpose.  It is provided "as is"
  without express or implied warranty.
 
  U.R.I. DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING ALL
  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT SHALL U.R.I.
  BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION
  OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN 
  CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

/*
  Create a window which shows (using a scrolling list widget) the files that
  a usr wants to browse. When the user clicks on one of the filenames, that
  file is browsed. The image currently being browsed is always highlighted.
*/

/* $Log: image_list_window.c,v $
 * Revision 1.1  1993/02/02  16:12:32  jimg
 * Initial revision
 *
 */

static char rcsid[]="$Id: image_list_window.c,v 1.1 1993/02/02 16:12:32 jimg Exp jimg $";

#include <stdio.h>
#include <time.h>

#include <rpc/rpc.h>

#ifdef AUX
#include <compat.h>
#endif 

#include <X11/Intrinsic.h>	/* toolkit */
#include <X11/StringDefs.h>
#include <X11/Shell.h>

#include <X11/Xaw/Command.h>	/* widget public includes */
#include <X11/Xaw/Form.h>
#include <X11/Xaw/Viewport.h>
#include <X11/Xaw/Box.h>
#include <X11/Xaw/List.h>

#ifdef MALLOC_DEBUG
#include <malloc.h>
#endif 

#include "errmsg.h"
#include "comm.h"

#include "vertex.h"
#include "region.h"
#include "ximage.h"
#include "pyramid.h"
#include "pixmap-mark.h"
#include "xbt-const.h"
#include "xbt-types.h"
#include "xbt.h"
#include "dialog.h"
#include "browse.h"
#include "xbrowse.h"

static Widget the_list;		/* widgets used by several functions */
static Widget current_action;

extern XtAppContext a_context;	/* for portability */
extern APPDATA a_data;		/* application spec resources */

extern int screen_num;		/* number of default screen */
extern Display *display;	/* user's display */

extern Widget pause_tx;		/* button widgets defined in callbacks.c */
extern Widget region_use;

extern BROWSE *browse;		/* defined in callbacks.c */
extern XDR_TCP *server;

static  void image_click();

void
create_image_list_window(server, browse)
XDR_TCP *server;
BROWSE *browse;
{
    Widget image_list;		/* window created by these functions */
    Widget form;
    Widget info_label;
    Widget list_view;
    String image_list_str = (String)browse->image_list;

    image_list = XtAppCreateShell
	("Images to Browse", "ImageList", applicationShellWidgetClass,
	 display, NULL, (Cardinal)0);

    form = XtVaCreateManagedWidget
	("form", formWidgetClass, image_list, NULL);

    info_label = XtVaCreateManagedWidget
	("information", labelWidgetClass, form, XtNleft, XtChainLeft, XtNtop,
	 XtChainTop, XtNright, XtChainRight, XtNbottom, XtChainTop, NULL);

    current_action = XtVaCreateManagedWidget
	("currentAction", labelWidgetClass, form, XtNleft, XtChainLeft,
	 XtNtop, XtChainTop, XtNright, XtChainRight, XtNbottom, XtChainTop,
	 XtNresize, TRUE, NULL); 
    
    list_view = XtVaCreateManagedWidget
	("listView", viewportWidgetClass, form,
	 XtNleft, XtChainLeft, XtNtop, XtChainTop, XtNright, XtChainRight,
	 XtNbottom, XtChainBottom, XtNallowVert, TRUE, XtNuseRight, TRUE,
	 XtNresizable, TRUE, NULL);
    
    the_list = XtVaCreateManagedWidget
	("theList", listWidgetClass, list_view, XtNforceColumns, TRUE,
	 XtNdefaultColumns, 1, XtNverticalList, TRUE,
	 XtNleft, XtChainLeft, XtNtop, XtChainTop, XtNright, XtChainRight,
	 XtNbottom, XtChainBottom, XtNpasteBuffer, TRUE, NULL);  

    XawListChange(the_list, browse->pretty_list,
		  browse->image_list_len, 0, TRUE);
    XawListHighlight(the_list, 0);
    
    XtAddCallback(the_list, XtNcallback, image_click, NULL);

    XtRealizeWidget(image_list);
}

static void
image_click(w, client_data, call_data)
Widget w;
XtPointer client_data;
XtPointer call_data;
{
    XawListReturnStruct *lrs = (XawListReturnStruct *)call_data;

    if (lrs->list_index == XAW_LIST_NONE)
	return;
    
    browse->current_image = lrs->list_index - 1;
    XtVaSetValues(current_action, XtNlabel, "Retrieving image from archive...",
		  NULL); 
    XFlush(display);
    
    /* copied from callbacks:next_button() */
    browse->accumulate_cost_p = FALSE;
    do_stop_image_tx(server, browse);

    stop_browse_image(browse);		
    print_browse_stats(browse);
    XtSetSensitive(pause_tx, True);
    XtVaSetValues(pause_tx, XtNlabel, "Pause", NULL);
    if (browse->region_defd_p)
	XtSetSensitive(region_use, TRUE);
    (void) do_next_image(server, browse);

    XtVaSetValues(current_action, XtNlabel, "", NULL);
    XFlush(display);
}

void
highlight_current_image()
{
    XawListHighlight(the_list, browse->current_image);
}
