
#include <stdio.h>
#include <stdlib.h>

#include <X11/Intrinsic.h>

/*
  Given a pathname and a filename, concatenate the two if the filename does not
  begin with a slash (i.e., it is a relative filename). If the filename is
  absolute do not concatenate with pathname. Allocates memory for the
  resultant string and returns a pointer to it.

  9/20/91
  Added allocation for else case so that callers don't wind up freeing space
  allocated to `filename'.

  10/21/91
  Fixed bug when filename is relative and pal_path is '\0'. Added ~ expansion.
*/

/* $Log: make-pathname.c,v $
 * Revision 1.4  1993/02/02  16:12:32  jimg
 * Added conditional include for debugging malloc header.
 *
 * Revision 1.3  1992/10/21  17:17:03  jimg
 * Fixed memory allocation bug.
 *
 * Revision 1.3  1992/10/21  17:17:03  jimg
 * Fixed memory allocation bug.
 *
 * Revision 1.2  1992/10/14  13:19:00  jimg
 * Minor bug fixes.
 *
 * Revision 1.1  1992/03/23  20:39:01  jimg
 * Initial revision
 *
 * Revision 1.1  1992/03/23  20:39:01  jimg
 * Initial revision
 *
 */

static char rcsid[]="$Id: make-pathname.c,v 1.4 1993/02/02 16:12:32 jimg Exp jimg $";

#ifdef MALLOC_DEBUG
#include <malloc.h>
#endif 

char *
make_pathname(pathname, filename)
char *pathname;
char *filename;
{
    char *fullname;

    if (filename[0] == '/') {
        /* we want to allocate a new block of memory for the filename even 
	   if fullname is just filename (which is the case when filename
	   is an absolute path. */
	fullname = XtNewString(filename);
	return fullname;
    }
    else if (filename[0] == '~') {
	char *home = getenv("HOME");
	if (!home)
	    home = "";		/* make sure that home points somewhere */
	fullname = (char *)XtMalloc(strlen(filename) + strlen(home) + 2);
	strcpy(fullname, home);
	if (home[0] && (home[strlen(home) - 1] != '/'))
	    strcat(fullname, "/");
	if (filename[1] == '/')	/* don't copy `~' and/or `/' */
	    strcat(fullname, &filename[2]);
	else
	    strcat(fullname, &filename[1]);
	return fullname;
    }
    else {			/* filename must be a relative path; prefix
				   with pal_path */ 
	fullname = (char *)XtMalloc(strlen(filename) + strlen(pathname) + 2);
	strcpy(fullname, pathname);
	if (pathname[0] && (pathname[strlen(pathname) - 1] != '/'))
	    strcat(fullname, "/");
	strcat(fullname, filename);
	return fullname;
    }
}
