#ifndef __PYRANID_H
#define __PYRANID_H

/*
  struct definition and functions declarations for pyramid.c
  
  jhrg
  
  Modifications
  
  7/26/90 - Added ClearDisplay function.

  12/11/90 - Ported to unix/X. Changed the type IMGFILE (from Dsp) to
  Pixmap. 

  2/14/91 - Moved XImage to this structure.

  2/15/91 - Added second XImage.

  5/2/91 - added origin_{x,y}. These keep track of the pixel that is at the
  window's top,left corner. Used in printLocation (xbrowse.c)
*/

#define PAL_MAX 256
#define MAX_STR_LEN 256

#if defined(MACROS)

#define unitize(a, unit) (( (long) a / (long) unit) * (long) unit)

#define ceil_level(x, y) ((long) ceil(M_LOG2E \
				       * log((double) ((x > y) ? x : y))))

#define floor_level(x, y) ((long) floor(M_LOG2E \
					* log((double) ((x < y) ? x : y))))

#define sample_interval(p) ((p->optimize && p->optimize_row)\
			    ? p->scale_factor << 1 \
			    : p->scale_factor)
#endif /* MACROS */

struct image_header {
    char image_name[MAX_STR_LEN]; /* human readable */
    char projection[MAX_STR_LEN]; /* human readable (e.g., `Linear') */
    char sat_type[MAX_STR_LEN]; /* human readable (`noaa 7') */
    char data_units[MAX_STR_LEN]; /* human readable (e.g., degress C) */

    char y_to_lat[MAX_STR_LEN];	/* unused */
    char x_to_lon[MAX_STR_LEN];
    char lat_to_y[MAX_STR_LEN];
    char lon_to_x[MAX_STR_LEN];
    char data_eqn[MAX_STR_LEN]; /* unused */
    
    float top_left_lat;		/* latitude of top-left pixel */
    float top_left_lon;		/* longitude of top-left pixel */
    float bot_right_lat;	/* latitude of top-left pixel */
    float bot_right_lon;	/* longitude of top-left pixel */

    float temp_slope;		/* temperature slope */
    float temp_intcp;		/* temperature intercapt */
    float resolution;		/* imax res in km/pixel */
};

struct pyramid {
    long current_row;		/* index of current row on the display */
    long image_current_row;	/* current row on the server */
    long scale_factor;		/* number of pixels/block */
    long init_level;		/* first level server will transmit */
    long max_pyramid_level;	/* highest level the window can display */
    long max_image_level;	/* highest level the image can have */
    long level_ratio;		/* ratio of max_pyramid and max_image levels */
    long image_origin_x;	/* x,y coor of pixel at window's origin */
    long image_origin_y;	/* in the image's coordinate system */
    long level;			/* current level (0, 1, 2, ... ) */
    long users_max_level;	/* max level to display - restrict data */
    char palette[PAL_MAX];	/* image values to screen values */
    long image_size_x;		/* M for the M x N image */
    long image_size_y;
#ifdef NEVER
    double top_left_lat;		/* latitude of top left pixel */
    double top_left_lon;
    double bot_right_lat;	/* latitude of bottom right pixel */
    double bot_right_lon;
    double temp_slope;		/* slope of temperature function */
    double temp_intcp;		/* intercept of temperature function */
#endif

    struct image_header *header; /* new (ver 3.2) header info */
    
    XImage *raw_image;		/* store the original data here */
    XImage *image;		/* used in XPutImage to get a row in the
				   Pixmap that stores the offscreen image */
    REGION *region;		/* constrain to this region */
    REGION *image_region;	/* region containing whole image */
    REGION *user_region;	/* region defined by user (mouse or file) */
};

typedef struct pyramid PYRAMID;

PYRAMID *init_pyramid();
void free_pyramid();
long reset_pyramid();
void display_pyramid();
long pyramid_next_level();
void null_image_header();  
long add_sampled_row();
void copy_using_palette();
void update_display();
long can_zoom();
long pyramid_zoom_factor();
void zoom_pyramid();
double get_temperature();
void get_lat_lon();
void get_x_y();
long image_to_screen_x();
long image_to_screen_y();
long screen_to_image_x();
long screen_to_image_y();

#ifndef MACROS
long ceil_level();
long floor_level();
long unitize();
#endif

#endif /* __PYRANID_H */
